@@ -1,6 +1,6 @@
 #!/usr/bin/perl -T
 ###
-###              analog 5.22             http://www.analog.cx/
+###              analog 5.23             http://www.analog.cx/
 ### This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
 ### stated otherwise. Distribution, usage and modification of this program is
 ### subject to the conditions of the Licence which you should have received
@@ -13,8 +13,8 @@
 
 # 1) uncomment (remove everything before $analog) and edit one of the next two
 #    lines to give the location (full pathname) of the analog executable.
-#       Unix: $analog = '/usr/local/etc/httpd/analog-5.22/analog';
-#       Windows: $analog = 'C:\program files\analog 5.22\analog.exe';
+#       Unix: $analog = '/usr/local/etc/httpd/analog-5.23/analog';
+#       Windows: $analog = 'C:\program files\analog 5.23\analog.exe';
 # 2) If you're on Unix, edit the first line in this file to give the location
 #    of Perl (don't remove the #! though).
 # 3) You also need to edit anlgform.html if you want to use the form.
@@ -23,7 +23,7 @@
 @forbidden = qw(LOGFORMAT APACHELOGFORMAT DEFAULTLOGFORMAT
 		APACHEDEFAULTLOGFORMAT HEADERFILE FOOTERFILE UNCOMPRESS
 		OUTFILE CACHEOUTFILE LOCALCHARTDIR ERRFILE DNS CGI
-		SETTINGS LANGFILE DESCFILE);
+		SETTINGS PROGRESSFREQ LANGFILE DESCFILE);
 # Forbidden commands: sysadmin can add more (must be in upper case!)
 # Other commands you might consider adding, because they allow users to
 # specify which files to use for the analysis, are LOGFILE and DOMAINSFILE.
@@ -103,7 +103,8 @@ foreach $k (@order) {
                $k =~ /[^A-Z12]/ || $k eq '' || $k =~ /^IGNORE/);
                # other stuff not wanted
 }
-# Special case: must come last
+# Special cases: must come last
+print ANALOG "DEBUG -C\n";
 printargs('CM', 'CONFIGFILE') unless forbidden('CM');
 # again, both 'CM' and 'CONFIGFILE' must be allowed for this to happen.
 print ANALOG "OUTFILE stdout\n";
