@@ -1,4 +1,4 @@
-/***             analog 5.22             http://www.analog.cx/             ***/
+/***             analog 5.23             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -406,14 +406,14 @@
    CZECH_1250, DANISH, DUTCH, ENGLISH, US_ENGLISH, FINNISH, FRENCH, GERMAN,
    HUNGARIAN, ITALIAN, JAPANESE_EUC, JAPANESE_JIS, JAPANESE_SJIS, JAPANESE_UTF,
    KOREAN, LATVIAN, NORWEGIAN (Bokmal), NYNORSK, POLISH, PORTUGUESE,
-   BR_PORTUGUESE, SERBIAN, SLOVENE, SLOVENE_1250, SPANISH, SWEDISH,
-   SWEDISH_ALT, TURKISH or UKRAINIAN.
+   BR_PORTUGUESE, RUSSIAN, RUSSIAN_1251, SERBIAN, SLOVENE, SLOVENE_1250,
+   SPANISH, SWEDISH, SWEDISH_ALT, TURKISH or UKRAINIAN.
    *
    The following languages were available for previous versions of analog, but
    have not yet been translated for version 5. As they are translated, they
    will be added to the analog home page:
    BOSNIAN, SIMP_CHINESE (GB2312), CROATIAN, GREEK, ICELANDIC, LITHUANIAN,
-   ROMANIAN, RUSSIAN and SLOVAK. */
+   ROMANIAN and SLOVAK. */
 #endif
 
 #define MARKCHAR '+'
