@@ -1,4 +1,4 @@
-/***             analog 5.22             http://www.analog.cx/             ***/
+/***             analog 5.23             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -14,7 +14,7 @@
 
 /*** OS specific things ***/
 
-#define VNUMBER "5.22"    /* the version number of this program */
+#define VNUMBER "5.23"    /* the version number of this program */
 
 #undef VERSION /* If no OS set, compilation will fail by not knowing VERSION */
 
@@ -25,6 +25,7 @@
 
 #ifdef __BEOS__
 #undef MAC
+#undef BEOS
 #define BEOS
 #endif
 
@@ -362,7 +363,11 @@ typedef unsigned long IN_ADDR_T;
 #include <netdb.h>
 #ifndef BEOS
 #include <arpa/inet.h>
+#else
+#ifdef BONE_VERSION
+#include <arpa/inet.h>
 #endif
+#endif  /* BEOS */
 #define INET_ADDR_ERR ((IN_ADDR_T)(-1))
 #endif  /* !WIN32 */
 #endif  /* !MAC */
@@ -592,8 +597,8 @@ enum {ARMENIAN, /*BOSNIAN,*/ BULGARIAN, BULGARIAN_MIK, CATALAN,
       DUTCH, ENGLISH, US_ENGLISH, FINNISH, FRENCH, GERMAN, /*GREEK,*/
       HUNGARIAN, /*ICELANDIC,*/ ITALIAN, JAPANESE_EUC, JAPANESE_JIS,
       JAPANESE_SJIS, JAPANESE_UTF, KOREAN, LATVIAN, /*LITHUANIAN,*/
-      NORWEGIAN, NYNORSK, POLISH, PORTUGUESE, BR_PORTUGUESE,
-      /*ROMANIAN, RUSSIAN,*/ SERBIAN, /*SLOVAK,*/ SLOVENE, SLOVENE_1250,
+      NORWEGIAN, NYNORSK, POLISH, PORTUGUESE, BR_PORTUGUESE, /*ROMANIAN,*/
+      RUSSIAN, RUSSIAN_1251, SERBIAN, /*SLOVAK,*/ SLOVENE, SLOVENE_1250,
       SPANISH, SWEDISH, SWEDISH_ALT, TURKISH, UKRAINIAN};
 #define OLDLANG (-2)
 
