@@ -1,4 +1,4 @@
-/***             analog 5.22             http://www.analog.cx/             ***/
+/***             analog 5.23             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -109,8 +109,8 @@ char *country[] = {"am", /*"ba",*/ "bg", "bgm", "cat", /*"cn",*/ "tw",
 		   /*"hr",*/ "cz", "cz1", "dk", "nl", "uk", "us", "fi",
 		   "fr", "de", /*"gr",*/ "hu", /*"is",*/ "it", "jpe", "jpj",
 		   "jps", "jpu", "kr", "lv", /*"lt",*/ "no", "no2", "pl", "pt",
-		   "br", /*"ro", "ru",*/ "yu", /*"sk",*/ "si", "si1", "es",
-		   "se", "se2", "tr", "ua"};
+		   "br", /*"ro",*/ "ru", "ru1", "yu", /*"sk",*/ "si", "si1",
+		   "es", "se", "se2", "tr", "ua"};
 /* Report code letters in order of enum in anlghea3.h */
 /* Any new ones must also be added to reportorder in anlghea2.h */
 char repcodes[] = "1QmWDH45dhw67xrEItiSlLofskKBvRMujJZNnYybpzcP";
