@@ -1,4 +1,4 @@
-/***             analog 5.22             http://www.analog.cx/             ***/
+/***             analog 5.23             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -107,7 +107,11 @@ void settings(Options *op, int argc, char *argv[]) {
     if (STREQ(argv[i], "-help") || STREQ(argv[i], "-version") ||
 	STREQ(argv[i], "--help") || STREQ(argv[i], "--version")) {
       fprintf(stderr, "This is analog version %s\n", VERSION);
-      fprintf(stderr, "For help see docs/Readme.html, or %s\n", ANALOGURL);
+      fprintf(stderr, "For help see docs/Readme.html, "
+#ifdef UNIX
+	      "or man analog, "
+#endif
+	      "or %s\n", ANALOGURL);
       my_exit(EXIT_SUCCESS);
     }
   }
