@@ -1,4 +1,4 @@
-/***             analog 5.22             http://www.analog.cx/             ***/
+/***             analog 5.23             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -218,10 +218,12 @@ Choices langchoices[] = {{"ARMENIAN", ARMENIAN}, {"BOSNIAN", OLDLANG},
   {"BOKMAAL", NORWEGIAN}, {"NYNORSK", NYNORSK}, {"POLISH", POLISH},
   {"PORTUGUESE", PORTUGUESE}, {"PORTUGESE", PORTUGUESE},
   {"BR-PORTUGUESE", BR_PORTUGUESE}, {"BR-PORTUGESE", BR_PORTUGUESE},
-  {"BRAZILIAN", BR_PORTUGUESE}, {"ROMANIAN", OLDLANG}, {"RUSSIAN", OLDLANG},
+  {"BRAZILIAN", BR_PORTUGUESE}, {"ROMANIAN", OLDLANG}, {"RUSSIAN", RUSSIAN},
+  {"RUSSIAN-1251", RUSSIAN_1251},
   {"SERBIAN", SERBIAN}, {"SERBOCROATIAN", SERBIAN}, {"SERBOCROAT", SERBIAN},
   {"SLOVAK", OLDLANG}, {"SLOVENE", SLOVENE}, {"SLOVENIAN", SLOVENE},
-  {"SLOVENE-1250", SLOVENE}, {"SLOVENIAN-1250", SLOVENE}, {"SPANISH", SPANISH},
+  {"SLOVENE-1250", SLOVENE_1250}, {"SLOVENIAN-1250", SLOVENE_1250},
+  {"SPANISH", SPANISH},
   {"SWEDISH", SWEDISH}, {"SWEDISH-ALT", SWEDISH_ALT}, {"TURKISH", TURKISH},
   {"UKRAINIAN", UKRAINIAN}, {"UKRANIAN", UKRAINIAN}, {"", 0}};
 Choices onoffchoices[] = {{"ON", TRUE}, {"TRUE", TRUE}, {"OFF", FALSE},
