@@ -1,4 +1,4 @@
-/***             analog 5.22             http://www.analog.cx/             ***/
+/***             analog 5.23             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -344,8 +344,9 @@ void timerep(FILE *outf, Outchoices *od, choice rep, Dateman *dman,
 	save = ((dp != dman->lastdp || j <= lasttime) &&
 		(dp != dman->firstdp || j + (int)relgran > firsttime));
       if (save) {
-	while (rep == REP_WEEK && DAYOFWEEK(i) != od->weekbeginson)
+	while (rep == REP_WEEK && DAYOFWEEK(i) != od->weekbeginson && i > 1)
 	  i--;  /* earliest week: account under first day of week */
+	/* (i > 1 above stops us crashing by going back further than 1/1/70) */
 	if (rep == REP_QUARTERLY && i == dman->firstdate)
 	  i = DATE2CODE(year, (month / 3) * 3, 1);
 	/* sim. first date of quarter: month, year were calculated above */
@@ -542,6 +543,7 @@ void printtree(FILE *outf, Outchoices *od, choice rep, Hashtable *tree,
   char *name;
   size_t need = (size_t)level + 3;
   logical rightalign;
+  unsigned long datar, datar7, datap, datap7, datad, datafd;
   Hashindex *p;
   Strlist *pn, s;
   unsigned long goodn = 0;
@@ -557,21 +559,24 @@ void printtree(FILE *outf, Outchoices *od, choice rep, Hashtable *tree,
 	rightalign = FALSE;
       else
 	rightalign = possrightalign;
-      (void)printcols(outf, od, rep, p->own->data[requests],
-		      (requests7 >= 0)?(p->own->data[requests7]):0,
-		      (pages >= 0)?(p->own->data[pages]):0,
-		      (pages7 >= 0)?(p->own->data[pages7]):0,
+      datar = p->own->data[requests];
+      datar7 = (requests7 >= 0)?(p->own->data[requests7]):0;
+      datap = (pages >= 0)?(p->own->data[pages]):0;
+      datap7 = (pages7 >= 0)?(p->own->data[pages7]):0;
+      datad = (date >= 0)?(p->own->data[date]):0;
+      datafd = (firstd >= 0)?(p->own->data[firstd]):0;
+      (void)printcols(outf, od, rep, datar, datar7, datap, datap7,
 		      p->own->bytes, p->own->bytes7,
 		      (level == 0)?((long)(++goodn)):(-1), (int)level + 1,
 		      totr, totr7, totp, totp7, totb, totb7, width, bmult,
 		      bmult7, unit, FALSE, rightalign, name,
 		      (logical)(p->own->ispage), 2 * level, linkhead, baseurl,
 		      lngstr[genrepdate_], lngstr[genreptime_],
-		      p->own->data[date] / 1440,
-		      (p->own->data[date] % 1440) / 60,
-		      p->own->data[date] % 60, p->own->data[firstd] / 1440,
-		      (p->own->data[firstd] % 1440) / 60,
-		      p->own->data[firstd] % 60);
+		      (datecode_t)(datad / 1440),
+		      (unsigned int)((datad % 1440) / 60),
+		      (unsigned int)(datad % 60), (datecode_t)(datafd / 1440),
+		      (unsigned int)((datafd % 1440) / 60),
+		      (unsigned int)(datafd % 60));
       printtree(outf, od, rep, (Hashtable *)(p->other), requests, requests7,
 		pages, pages7, date, firstd, level + 1, pn, totr, totr7, totp,
 		totp7, totb, totb7, width, possrightalign, bmult, bmult7,
@@ -608,6 +613,7 @@ void genrep(FILE *outf, Outchoices *od, choice rep, Hashindex **gooditems,
   Hashtable *tree = NULL;  /* Just to keep compiler happy */
   Hashindex *p;
   Hashentry *badp;
+  unsigned long datar, datar7, datap, datap7, datad, datafd;
   unsigned long totr, totr7, totp, totp7, i = 0;
   unsigned long maxr, maxr7, maxp, maxp7, goodn, badn;
   double totb, totb7, maxb, maxb7, unit = 1.0;
@@ -704,20 +710,24 @@ void genrep(FILE *outf, Outchoices *od, choice rep, Hashindex **gooditems,
 	rightalign = TRUE;
       else
 	rightalign = FALSE;
-      (void)printcols(outf, od, rep, p->own->data[requests],
-		      (requests7 >= 0)?(p->own->data[requests7]):0,
-		      (pages >= 0)?(p->own->data[pages]):0,
-		      (pages7 >= 0)?(p->own->data[pages7]):0, p->own->bytes,
+      datar = p->own->data[requests];
+      datar7 = (requests7 >= 0)?(p->own->data[requests7]):0;
+      datap = (pages >= 0)?(p->own->data[pages]):0;
+      datap7 = (pages7 >= 0)?(p->own->data[pages7]):0;
+      datad = (date >= 0)?(p->own->data[date]):0;
+      datafd = (firstd >= 0)?(p->own->data[firstd]):0;
+      (void)printcols(outf, od, rep, datar, datar7, datap, datap7,
+		      p->own->bytes,
 		      p->own->bytes7, (long)(++goodn), 0, totr, totr7, totp,
 		      totp7, totb, totb7, width, bmult, bmult7, unit,
 		      (logical)(rep == REP_SIZE || rep == REP_PROCTIME),
 		      rightalign, p->name, p->own->ispage, 0, NULL, NULL,
 		      lngstr[genrepdate_], lngstr[genreptime_],
-		      p->own->data[date] / 1440,
-		      (p->own->data[date] % 1440) / 60,
-		      p->own->data[date] % 60, p->own->data[firstd] / 1440,
-		      (p->own->data[firstd] % 1440) / 60,
-		      p->own->data[firstd] % 60);
+		      (datecode_t)(datad / 1440),
+		      (unsigned int)((datad % 1440) / 60),
+		      (unsigned int)(datad % 60), (datecode_t)(datafd / 1440),
+		      (unsigned int)((datafd % 1440) / 60),
+		      (unsigned int)(datafd % 60));
     }
   }
 
@@ -729,20 +739,24 @@ void genrep(FILE *outf, Outchoices *od, choice rep, Hashindex **gooditems,
   else
     notlistedstr = lngstr[notlistedn_];
   if (badn > 0) {
-    verbchar = printcols(outf, od, rep, badp->data[requests],
-			 (requests7 >= 0)?(badp->data[requests7]):0,
-			 (pages >= 0)?(badp->data[pages]):0,
-			 (pages7 >= 0)?(badp->data[pages7]):0, badp->bytes,
-			 badp->bytes7, -1, istree, totr, totr7, totp, totp7,
-			 totb, totb7, width, bmult, bmult7, unit,
+    datar = badp->data[requests];
+    datar7 = (requests7 >= 0)?(badp->data[requests7]):0;
+    datap = (pages >= 0)?(badp->data[pages]):0;
+    datap7 = (pages7 >= 0)?(badp->data[pages7]):0;
+    datad = (date >= 0)?(badp->data[date]):0;
+    datafd = (firstd >= 0)?(badp->data[firstd]):0;
+    verbchar = printcols(outf, od, rep, datar, datar7, datap, datap7,
+			 badp->bytes, badp->bytes7, -1, istree, totr, totr7,
+			 totp, totp7, totb, totb7, width, bmult, bmult7, unit,
 			 (logical)(rep == REP_SIZE || rep == REP_PROCTIME),
 			 FALSE, NULL, FALSE, 0, NULL, NULL,
 			 lngstr[genrepdate_], lngstr[genreptime_],
-			 badp->data[date] / 1440,
-			 (badp->data[date] % 1440) / 60, badp->data[date] % 60,
-			 badp->data[firstd] / 1440,
-			 (badp->data[firstd] % 1440) / 60,
-			 badp->data[firstd] % 60);
+			 (datecode_t)(datad / 1440),
+			 (unsigned int)((datad % 1440) / 60),
+			 (unsigned int)(datad % 60),
+			 (datecode_t)(datafd / 1440),
+			 (unsigned int)((datafd % 1440) / 60),
+			 (unsigned int)(datafd % 60));
     fprintf(outf, "[%s: ", notlistedstr);
     f3printf(outf, outstyle, (double)badn, 0, od->sepchar);
     if (outstyle == COMPUTER)
