@@ -1,4 +1,4 @@
-/***             analog 5.22             http://www.analog.cx/             ***/
+/***             analog 5.23             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -246,7 +246,9 @@ void myputc(FILE *outf, char c, choice outstyle) {
  ** So data is categorised according to its source, via an enum in anlghea3.h.
  ** In the following descriptions of the security levels, "convert" means
  ** converting e.g. < to &lt; and "escape" means using \< to prevent this
- ** happening.
+ ** happening. "unprintable" means characters set as unprintable in init.c:
+ ** note that this is only known unprintable characters 0x00 - 0x1F, 0x7F,
+ ** and in ISO-8859-* also 0x80-0x9F.
  **
  ** 1) TRUSTED: E.g. a string from a language file. Completely trusted. In
  **    single-byte mode, convert characters (for convenience not security), but
@@ -265,6 +267,9 @@ void myputc(FILE *outf, char c, choice outstyle) {
  **    an href uses escfprintf() instead of this function.)
  **/
 void htmlputs(FILE *outf, Outchoices *od, char *s, choice source) {
+#ifdef EBCDIC
+  extern unsigned char os_toascii[];
+#endif
   extern logical cgi;
   extern logical unprintable[256];
 
@@ -1480,7 +1485,7 @@ char printcols(FILE *outf, Outchoices *od, choice rep, unsigned long reqs,
 	       double unit, logical name1st, logical rightalign, char *name,
 	       logical ispage, unsigned int spaces, Include *linkhead,
 	       char *baseurl, char *datefmt, char *timefmt, datecode_t date,
-	       unsigned int hr, unsigned int min, unsigned int date2,
+	       unsigned int hr, unsigned int min, datecode_t date2,
 	       unsigned int hr2, unsigned int min2) {
   /* 'level' is -1 for time reports, 0 for other non-hierarchical reports,
      and starts at 1 for hierarchical reports. */
